Enum Source 

#[non_exhaustive]
pub enum Source { Breakpad(Breakpad), Elf(Elf), }
The source to use for the inspection request.

Objects of this type are used first and foremost with the Inspector::lookup and Inspector::for_each methods.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Breakpad(Breakpad)

Available on crate feature breakpad only.

The source is a Breakpad file.



Elf(Elf)

The source is an ELF file.

Implementations

Source

impl Source

pub fn path(&self) -> Option<&Path>

Retrieve the path to the source, if it has any.