Symbolized

Enum Symbolized 

pub enum Symbolized<'src> {
    Sym(Sym<'src>),
    Unknown(Reason),
}
An enumeration used as reporting vehicle for address symbolization.

Variants



Sym(Sym<'src>)

The input address was symbolized as the provided symbol.



Unknown(Reason)

The input address was not found and could not be symbolized.

The provided reason is a best guess, hinting at what ultimately prevented the symbolization from being successful.

Implementations

Source

impl<'src> Symbolized<'src>

pub fn as_sym(&self) -> Option<&Sym<'src>>

Convert the object into a Sym reference, if the corresponding variant is active.

pub fn into_sym(self) -> Option<Sym<'src>>

Convert the object into a Sym object, if the corresponding variant is active.